/label "Enhancement::Feature"

## Summary
(A concise of the feature.)


## Motivation
(Why is this feature needed?)


## Detailed Specification
(Provide a clear, technical description of what you want implemented.)


## Additional Context

- (Links to relevant literature (DOI, arXiv, journal))
- (Related issues or pull requests)
- (Sketches, plots, examples, ...)
